@@ -9,12 +9,12 @@
 
 import torch
 import torch.nn as nn
+from torch.nn.parallel import DistributedDataParallel as DDP
 
 from yacs.config import CfgNode
 
-from . import resnet, ghostnet, mobilenet, efficientnet, efficientnet_lite
-
 from zcls2.util import logging
+from . import resnet, ghostnet, mobilenet, efficientnet, efficientnet_lite
 
 logger = logging.get_logger(__name__)
 
@@ -47,10 +47,11 @@ def build_model(cfg: CfgNode, device: torch.device = torch.device('cpu')) -> nn.
         raise ValueError(f"{model_arch} does not support")
 
     if sync_bn:
-        import apex
-        logger.info("using apex synced BN")
-        model = apex.parallel.convert_syncbn_model(model)
+        logger.info("using synced BN")
+        # See https://pytorch.org/docs/stable/generated/torch.nn.SyncBatchNorm.html
+        torch.nn.SyncBatchNorm.convert_sync_batchnorm(model)
 
+    # See https://pytorch.org/tutorials/intermediate/memory_format_tutorial.html#converting-existing-models
     if cfg.CHANNELS_LAST:
         memory_format = torch.channels_last
     else:
@@ -58,4 +59,7 @@ def build_model(cfg: CfgNode, device: torch.device = torch.device('cpu')) -> nn.
     # Same as Apex setting
     model = model.to(device, memory_format=memory_format)
 
+    if cfg.DISTRIBUTED:
+        model = DDP(model)
+
     return model
